@@ -23,14 +23,14 @@ from pastml.models.jtt import JTT_STATES, JTT, JTT_FREQUENCIES
 from pastml.parsimony import is_parsimonious, parsimonious_acr, ACCTRAN, DELTRAN, DOWNPASS, MP_METHODS, MP, \
     get_default_mp_method
 from pastml.tree import name_tree, annotate_dates, DATE, read_forest, DATE_CI, resolve_trees, IS_POLYTOMY, \
-    unresolve_trees
+    unresolve_trees, clear_extra_features
 from pastml.visualisation import get_formatted_date
 from pastml.visualisation.cytoscape_manager import visualize, TIMELINE_SAMPLED, TIMELINE_NODES, TIMELINE_LTT, \
     DIST_TO_ROOT_LABEL, DATE_LABEL
 from pastml.visualisation.itol_manager import generate_itol_annotations
 from pastml.visualisation.tree_compressor import REASONABLE_NUMBER_OF_TIPS
 
-PASTML_VERSION = '1.9.30'
+PASTML_VERSION = '1.9.33'
 
 warnings.filterwarnings("ignore", append=True)
 
@@ -454,7 +454,8 @@ def pastml_pipeline(tree, data=None, data_sep='\t', id_index=0,
                     out_data=None, html_compressed=None, html=None, html_mixed=None, work_dir=None,
                     verbose=False, forced_joint=False, upload_to_itol=False, itol_id=None, itol_project=None,
                     itol_tree_name=None, offline=False, threads=0, reoptimise=False, focus=None,
-                    resolve_polytomies=False, smoothing=False, frequency_smoothing=False):
+                    resolve_polytomies=False, smoothing=False, frequency_smoothing=False,
+                    pajek=None):
     """
     Applies PastML to the given tree(s) with the specified states and visualises the result (as html maps).
 
@@ -596,6 +597,9 @@ def pastml_pipeline(tree, data=None, data_sep='\t', id_index=0,
     :type out_data: str
     :param html_compressed: path to the output compressed visualisation file (html).
     :type html_compressed: str
+    :param pajek: path to the output vertically compressed visualisation file (Pajek NET Format).
+        Prooduced only if html_compressed is specified.
+    :type pajek: str
     :param html: (optional) path to the output tree visualisation file (html).
     :type html: str
     :param html_mixed: (optional) path to the output mostly compressed map visualisation file (html),
@@ -674,6 +678,7 @@ def pastml_pipeline(tree, data=None, data_sep='\t', id_index=0,
     itol_result = None
     new_tree = os.path.join(work_dir, get_named_tree_file(tree))
     features = [DATE, DATE_CI] + list(column2states.keys())
+    clear_extra_features(roots, features)
     nwks = [root.write(format_root_node=True, format=3, features=features) for root in roots]
     with open(new_tree, 'w+') as f:
         f.write('\n'.join(nwks))
@@ -776,7 +781,7 @@ def pastml_pipeline(tree, data=None, data_sep='\t', id_index=0,
         visualize(roots, column2states=column2states, html=html, html_compressed=html_compressed, html_mixed=html_mixed,
                   name_column=name_column, tip_size_threshold=tip_size_threshold, date_label=age_label,
                   timeline_type=timeline_type, work_dir=work_dir, local_css_js=offline, column2colours=colours,
-                  focus=focus)
+                  focus=focus, pajek=pajek)
 
     if threads > 1:
         async_result.wait()
@@ -1174,6 +1179,9 @@ def main():
                            .format(', '.join(MARGINAL_ML_METHODS)))
     out_group.add_argument('--html_compressed', required=False, default=None, type=str,
                            help="path to the output compressed map visualisation file (html).")
+    out_group.add_argument('--pajek', required=False, default=None, type=str,
+                           help="path to the output vertically compressed visualisation file (Pajek NET Format). "
+                                "Prooduced only if --html_compressed is specified.")
     out_group.add_argument('--html', required=False, default=None, type=str,
                            help="path to the output full tree visualisation file (html).")
     out_group.add_argument('--html_mixed', required=False, default=None, type=str,
